@@ -35,4 +35,4 @@ def retryloop(attempts, timeout=None, delay=0, backoff=1):
     e.args = e.args + ("on attempt {0} of {1} after {2:.3f} seconds".format(
         i + 1, attempts, duration), )
 
-    raise
+    raise e
